
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/doc/HTML/pt_BR/skanlite ; rm -rf common )
( cd usr/doc/HTML/pt_BR/skanlite ; ln -sf /usr/share/doc/HTML/pt_BR//common common )
( cd usr/doc/HTML/pt/skanlite ; rm -rf common )
( cd usr/doc/HTML/pt/skanlite ; ln -sf /usr/share/doc/HTML/pt//common common )
( cd usr/doc/HTML/et/skanlite ; rm -rf common )
( cd usr/doc/HTML/et/skanlite ; ln -sf /usr/share/doc/HTML/et//common common )
( cd usr/doc/HTML/de/skanlite ; rm -rf common )
( cd usr/doc/HTML/de/skanlite ; ln -sf /usr/share/doc/HTML/de//common common )
( cd usr/doc/HTML/fr/skanlite ; rm -rf common )
( cd usr/doc/HTML/fr/skanlite ; ln -sf /usr/share/doc/HTML/fr//common common )
( cd usr/doc/HTML/nl/skanlite ; rm -rf common )
( cd usr/doc/HTML/nl/skanlite ; ln -sf /usr/share/doc/HTML/nl//common common )
( cd usr/doc/HTML/it/skanlite ; rm -rf common )
( cd usr/doc/HTML/it/skanlite ; ln -sf /usr/share/doc/HTML/it//common common )
( cd usr/doc/HTML/es/skanlite ; rm -rf common )
( cd usr/doc/HTML/es/skanlite ; ln -sf /usr/share/doc/HTML/es//common common )
( cd usr/doc/HTML/sv/skanlite ; rm -rf common )
( cd usr/doc/HTML/sv/skanlite ; ln -sf /usr/share/doc/HTML/sv//common common )
( cd usr/doc/HTML/uk/skanlite ; rm -rf common )
( cd usr/doc/HTML/uk/skanlite ; ln -sf /usr/share/doc/HTML/uk//common common )
( cd usr/doc/HTML/en/skanlite ; rm -rf common )
( cd usr/doc/HTML/en/skanlite ; ln -sf /usr/share/doc/HTML/en/common common )
